<?php

namespace Litecms\Affiliateprogram\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Affiliateprogram\Models\AffiliateProgram;

class AffiliateProgramPolicy
{

    /**
     * Determine if the given user can view the affiliate_program.
     *
     * @param UserPolicy $user
     * @param AffiliateProgram $affiliate_program
     *
     * @return bool
     */
    public function view(UserPolicy $user, AffiliateProgram $affiliate_program)
    {
        if ($user->canDo('affiliateprogram.affiliate_program.view') && $user->isAdmin()) {
            return true;
        }

        return $affiliate_program->user_id == user_id() && $affiliate_program->user_type == user_type();
    }

    /**
     * Determine if the given user can create a affiliate_program.
     *
     * @param UserPolicy $user
     * @param AffiliateProgram $affiliate_program
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('affiliateprogram.affiliate_program.create');
    }

    /**
     * Determine if the given user can update the given affiliate_program.
     *
     * @param UserPolicy $user
     * @param AffiliateProgram $affiliate_program
     *
     * @return bool
     */
    public function update(UserPolicy $user, AffiliateProgram $affiliate_program)
    {
        if ($user->canDo('affiliateprogram.affiliate_program.edit') && $user->isAdmin()) {
            return true;
        }

        return $affiliate_program->user_id == user_id() && $affiliate_program->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given affiliate_program.
     *
     * @param UserPolicy $user
     * @param AffiliateProgram $affiliate_program
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AffiliateProgram $affiliate_program)
    {
        return $affiliate_program->user_id == user_id() && $affiliate_program->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given affiliate_program.
     *
     * @param UserPolicy $user
     * @param AffiliateProgram $affiliate_program
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AffiliateProgram $affiliate_program)
    {
        if ($user->canDo('affiliateprogram.affiliate_program.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given affiliate_program.
     *
     * @param UserPolicy $user
     * @param AffiliateProgram $affiliate_program
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AffiliateProgram $affiliate_program)
    {
        if ($user->canDo('affiliateprogram.affiliate_program.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
