<?php

namespace Litecms\Affiliateprogram\Providers;

use Illuminate\Support\ServiceProvider;

class AffiliateprogramServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'affiliateprogram');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'affiliateprogram');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.affiliateprogram', function ($app) {
            return $this->app->make('Litecms\Affiliateprogram\Affiliateprogram');
        });

                // Bind AffiliateProgram to repository
        $this->app->bind(
            'Litecms\Affiliateprogram\Interfaces\AffiliateProgramRepositoryInterface',
            \Litecms\Affiliateprogram\Repositories\Eloquent\AffiliateProgramRepository::class
        );

        $this->app->register(\Litecms\Affiliateprogram\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Affiliateprogram\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.affiliateprogram'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/affiliateprogram.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/affiliateprogram')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/affiliateprogram')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
